@@ -110,6 +110,7 @@ static int perform_extraction(alpm_handle_t *handle, struct archive *archive,
 		struct archive_entry *entry, const char *filename)
 {
 	int ret;
+	struct archive *archive_writer;
 	const int archive_flags = ARCHIVE_EXTRACT_OWNER |
 	                          ARCHIVE_EXTRACT_PERM |
 	                          ARCHIVE_EXTRACT_TIME |
@@ -118,7 +119,20 @@ static int perform_extraction(alpm_handle_t *handle, struct archive *archive,
 
 	archive_entry_set_pathname(entry, filename);
 
-	ret = archive_read_extract(archive, entry, archive_flags);
+	archive_writer = archive_write_disk_new();
+	if (archive_writer == NULL) {
+		_alpm_log(handle, ALPM_LOG_ERROR, _("cannot allocate disk archive object"));
+		alpm_logaction(handle, ALPM_CALLER_PREFIX,
+				"error: cannot allocate disk archive object");
+		return 1;
+	}
+
+	archive_write_disk_set_options(archive_writer, archive_flags);
+
+	ret = archive_read_extract2(archive, entry, archive_writer);
+
+	archive_write_free(archive_writer);
+
 	if(ret == ARCHIVE_WARN && archive_errno(archive) != ENOSPC) {
 		/* operation succeeded but a "non-critical" error was encountered */
 		_alpm_log(handle, ALPM_LOG_WARNING, _("warning given when extracting %s (%s)\n"),
@@ -405,6 +419,10 @@ static int commit_single_pkg(alpm_handle_t *handle, alpm_pkg_t *newpkg,
 	alpm_event_package_operation_t event;
 	const char *log_msg = "adding";
 	const char *pkgfile;
+	struct archive *archive;
+	struct archive_entry *entry;
+	int fd, cwdfd;
+	struct stat buf;
 
 	ASSERT(trans != NULL, return -1);
 
@@ -466,7 +484,7 @@ static int commit_single_pkg(alpm_handle_t *handle, alpm_pkg_t *newpkg,
 		}
 	}
 
-	/* prepare directory for database entries so permission are correct after
+	/* prepare directory for database entries so permissions are correct after
 	   changelog/install script installation */
 	if(_alpm_local_db_prepare(db, newpkg)) {
 		alpm_logaction(handle, ALPM_CALLER_PREFIX,
@@ -477,37 +495,45 @@ static int commit_single_pkg(alpm_handle_t *handle, alpm_pkg_t *newpkg,
 		goto cleanup;
 	}
 
-	if(!(trans->flags & ALPM_TRANS_FLAG_DBONLY)) {
-		struct archive *archive;
-		struct archive_entry *entry;
-		struct stat buf;
-		int fd, cwdfd;
+	fd = _alpm_open_archive(db->handle, pkgfile, &buf,
+			&archive, ALPM_ERR_PKG_OPEN);
+	if(fd < 0) {
+		ret = -1;
+		goto cleanup;
+	}
 
+	/* save the cwd so we can restore it later */
+	OPEN(cwdfd, ".", O_RDONLY | O_CLOEXEC);
+	if(cwdfd < 0) {
+		_alpm_log(handle, ALPM_LOG_ERROR, _("could not get current working directory\n"));
+	}
+
+	/* libarchive requires this for extracting hard links */
+	if(chdir(handle->root) != 0) {
+		_alpm_log(handle, ALPM_LOG_ERROR, _("could not change directory to %s (%s)\n"),
+				handle->root, strerror(errno));
+		_alpm_archive_read_free(archive);
+		if(cwdfd >= 0) {
+			close(cwdfd);
+		}
+		close(fd);
+		ret = -1;
+		goto cleanup;
+	}
+
+	if(trans->flags & ALPM_TRANS_FLAG_DBONLY) {
+		_alpm_log(handle, ALPM_LOG_DEBUG, "extracting db files\n");
+		while(archive_read_next_header(archive, &entry) == ARCHIVE_OK) {
+			const char *entryname = archive_entry_pathname(entry);
+			if(entryname[0] == '.') {
+				errors += extract_db_file(handle, archive, entry, newpkg, entryname);
+			} else {
+				archive_read_data_skip(archive);
+			}
+		}
+	} else {
 		_alpm_log(handle, ALPM_LOG_DEBUG, "extracting files\n");
 
-		fd = _alpm_open_archive(db->handle, pkgfile, &buf,
-				&archive, ALPM_ERR_PKG_OPEN);
-		if(fd < 0) {
-			ret = -1;
-			goto cleanup;
-		}
-
-		/* save the cwd so we can restore it later */
-		OPEN(cwdfd, ".", O_RDONLY | O_CLOEXEC);
-		if(cwdfd < 0) {
-			_alpm_log(handle, ALPM_LOG_ERROR, _("could not get current working directory\n"));
-		}
-
-		/* libarchive requires this for extracting hard links */
-		if(chdir(handle->root) != 0) {
-			_alpm_log(handle, ALPM_LOG_ERROR, _("could not change directory to %s (%s)\n"),
-					handle->root, strerror(errno));
-			_alpm_archive_read_free(archive);
-			close(fd);
-			ret = -1;
-			goto cleanup;
-		}
-
 		/* call PROGRESS once with 0 percent, as we sort-of skip that here */
 		PROGRESS(handle, progress, newpkg->name, 0, pkg_count, pkg_current);
 
@@ -532,33 +558,34 @@ static int commit_single_pkg(alpm_handle_t *handle, alpm_pkg_t *newpkg,
 			/* extract the next file from the archive */
 			errors += extract_single_file(handle, archive, entry, newpkg, oldpkg);
 		}
-		_alpm_archive_read_free(archive);
-		close(fd);
+	}
 
-		/* restore the old cwd if we have it */
-		if(cwdfd >= 0) {
-			if(fchdir(cwdfd) != 0) {
-				_alpm_log(handle, ALPM_LOG_ERROR,
-						_("could not restore working directory (%s)\n"), strerror(errno));
-			}
-			close(cwdfd);
+	_alpm_archive_read_free(archive);
+	close(fd);
+
+	/* restore the old cwd if we have it */
+	if(cwdfd >= 0) {
+		if(fchdir(cwdfd) != 0) {
+			_alpm_log(handle, ALPM_LOG_ERROR,
+					_("could not restore working directory (%s)\n"), strerror(errno));
 		}
+		close(cwdfd);
+	}
 
-		if(errors) {
-			ret = -1;
-			if(is_upgrade) {
-				_alpm_log(handle, ALPM_LOG_ERROR, _("problem occurred while upgrading %s\n"),
-						newpkg->name);
-				alpm_logaction(handle, ALPM_CALLER_PREFIX,
-						"error: problem occurred while upgrading %s\n",
-						newpkg->name);
-			} else {
-				_alpm_log(handle, ALPM_LOG_ERROR, _("problem occurred while installing %s\n"),
-						newpkg->name);
-				alpm_logaction(handle, ALPM_CALLER_PREFIX,
-						"error: problem occurred while installing %s\n",
-						newpkg->name);
-			}
+	if(errors) {
+		ret = -1;
+		if(is_upgrade) {
+			_alpm_log(handle, ALPM_LOG_ERROR, _("problem occurred while upgrading %s\n"),
+					newpkg->name);
+			alpm_logaction(handle, ALPM_CALLER_PREFIX,
+					"error: problem occurred while upgrading %s\n",
+					newpkg->name);
+		} else {
+			_alpm_log(handle, ALPM_LOG_ERROR, _("problem occurred while installing %s\n"),
+					newpkg->name);
+			alpm_logaction(handle, ALPM_CALLER_PREFIX,
+					"error: problem occurred while installing %s\n",
+					newpkg->name);
 		}
 	}
 
