@@ -24,6 +24,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <limits.h>
 
 /* libarchive */
 #include <archive.h>
@@ -356,7 +357,7 @@ int _alpm_pkg_validate_internal(alpm_handle_t *handle,
 }
 
 /**
- * Handle the existance of simple paths for _alpm_load_pkg_internal()
+ * Handle the existence of simple paths for _alpm_load_pkg_internal()
  * @param pkg package to change
  * @param path path to examine
  * @return 0 if path doesn't match any rule, 1 if it has been handled
@@ -695,22 +696,25 @@ error:
 	return NULL;
 }
 
+/* adopted limit from repo-add */
+#define MAX_SIGFILE_SIZE 16384
+
 static int read_sigfile(const char *sigpath, unsigned char **sig)
 {
 	struct stat st;
 	FILE *fp;
 
-	if(stat(sigpath, &st) != 0) {
-		return -1;
-	}
-
-	MALLOC(*sig, st.st_size, return -1);
-
 	if((fp = fopen(sigpath, "rb")) == NULL) {
-		free(*sig);
 		return -1;
 	}
 
+	if(fstat(fileno(fp), &st) != 0 || st.st_size > MAX_SIGFILE_SIZE) {
+		fclose(fp);
+		return -1;
+	}
+
+	MALLOC(*sig, st.st_size, fclose(fp); return -1);
+
 	if(fread(*sig, st.st_size, 1, fp) != 1) {
 		free(*sig);
 		fclose(fp);
@@ -762,6 +766,7 @@ int SYMEXPORT alpm_pkg_load(alpm_handle_t *handle, const char *filename, int ful
 
 			if(fail) {
 				_alpm_log(handle, ALPM_LOG_ERROR, _("required key missing from keyring\n"));
+				free(sigpath);
 				return -1;
 			}
 		}
