@@ -355,6 +355,10 @@ static int key_search(alpm_handle_t *handle, const char *fpr,
 /* value added in gpgme 1.5.0 */
 #if GPGME_VERSION_NUMBER >= 0x010500
 		case GPGME_PK_ECC:
+#endif
+/* value added in gpgme 1.7.0 */
+#if GPGME_VERSION_NUMBER >= 0x010700
+		case GPGME_PK_EDDSA:
 #endif
 			pgpkey->pubkey_algo = 'E';
 			break;
