@@ -17,8 +17,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-#ifndef _PM_PACKAGE_H
-#define _PM_PACKAGE_H
+#ifndef PM_PACKAGE_H
+#define PM_PACKAGE_H
 
 #include <alpm.h>
 
@@ -31,6 +31,6 @@ void dump_pkg_changelog(alpm_pkg_t *pkg);
 void print_installed(alpm_db_t *db_local, alpm_pkg_t *pkg);
 int dump_pkg_search(alpm_db_t *db, alpm_list_t *targets, int show_status);
 
-#endif /* _PM_PACKAGE_H */
+#endif /* PM_PACKAGE_H */
 
 /* vim: set noet: */
