@@ -17,8 +17,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-#ifndef _PM_UTIL_H
-#define _PM_UTIL_H
+#ifndef PM_UTIL_H
+#define PM_UTIL_H
 
 #include <stdlib.h>
 #include <stdarg.h>
@@ -82,6 +82,6 @@ int pm_vfprintf(FILE *stream, alpm_loglevel_t level, const char *format, va_list
 int pm_sprintf(char **string, alpm_loglevel_t level, const char *format, ...) __attribute__((format(printf,3,4)));
 int pm_vasprintf(char **string, alpm_loglevel_t level, const char *format, va_list args) __attribute__((format(printf,3,0)));
 
-#endif /* _PM_UTIL_H */
+#endif /* PM_UTIL_H */
 
 /* vim: set noet: */
